==> libslf4j-java_1.7.12.orig.tar.xz: libslf4j-java-1.7.12.orig/slf4j-ext/src/test/java/org/slf4j/dummyExt/MDCStrLookupTest.java <==
/**
 * Copyright (c) 2004-2011 QOS.ch
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */
package org.slf4j.dummyExt;

import junit.framework.TestCase;

import org.slf4j.MDC;
import org.slf4j.ext.MDCStrLookup;

public class MDCStrLookupTest extends TestCase {

    public MDCStrLookupTest(String name) {
        super(name);
    }

    public void setUp() throws Exception {
        super.setUp();
    }

    public void tearDown() throws Exception {
        super.tearDown();
    }

    public void testLookup() throws Exception {
        MDC.put("key", "value");
        MDC.put("number", "2");
        MDCStrLookup lookup = new MDCStrLookup();
        assertEquals("value", lookup.lookup("key"));
        assertEquals("2", lookup.lookup("number"));
        assertEquals(null, lookup.lookup(null));
        assertEquals(null, lookup.lookup(""));
        assertEquals(null, lookup.lookup("other"));
    }
}

==> libslf4j-java_1.7.14.orig.tar.xz: libslf4j-java-1.7.14/slf4j-ext/src/test/java/org/slf4j/dummyExt/MDCStrLookupTest.java <==
/**
 * Copyright (c) 2004-2011 QOS.ch
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */
package org.slf4j.dummyExt;

import static org.junit.Assert.assertEquals;

import org.junit.Test;
import org.slf4j.MDC;
import org.slf4j.ext.MDCStrLookup;
public class MDCStrLookupTest  {

    @Test
    public void testLookup() throws Exception {
        MDC.put("key", "value");
        MDC.put("number", "2");
        MDCStrLookup lookup = new MDCStrLookup();
        assertEquals("value", lookup.lookup("key"));
        assertEquals("2", lookup.lookup("number"));
        assertEquals(null, lookup.lookup(null));
        assertEquals(null, lookup.lookup(""));
        assertEquals(null, lookup.lookup("other"));
    }
}
